"use strict";

exports.__esModule = true;
exports.consoleErrors = void 0;
const originConsoleError = console.error;
let errors = [];
const ignoredErrors = ['findDOMNode is deprecated', 'uses the legacy childContextTypes API which is no longer supported', 'uses the legacy contextTypes API which is no longer supported'];
console.error = (...args) => {
  const shouldIgnoreError = args.some(arg => typeof arg === 'string' && ignoredErrors.some(ignoredError => arg.includes(ignoredError)));
  if (!shouldIgnoreError) {
    errors.push(args);
  }
  originConsoleError.apply(console, args);
};
const consoleErrors = exports.consoleErrors = {
  reset: () => errors = [],
  get: () => errors.slice().map(args => args.reduce((acc, arg) => {
    return acc + arg;
  }, ''))
};
beforeEach(() => errors = []);
afterEach(() => {
  if (errors.length > 0) {
    throw new Error(`Test has ${errors.length} Unhandled Errors:\n${errors}`);
  }
});
//# sourceMappingURL=index.js.map